package svc

import (
	"applet/app/admin/md"
	"applet/app/db"
	"applet/app/enum"
)

func CentralKitchenForSchoolInfo(enterpriseId int) (err error, resp md.CentralKitchenForSchoolInfoResp) {
	//1、查询`enterprise`
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(enterpriseId)
	if err != nil {
		return
	}
	resp.Name = enterprise.Name
	resp.Memo = enterprise.Memo
	resp.Kind = enum.EnterpriseKind(enterprise.Kind).String()
	resp.State = enum.EnterpriseState(enterprise.State).String()

	//2、查询`central_kitchen_for_school_with_spec`
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(enterpriseId)
	spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		return
	}
	if spec != nil {
		resp.IsOpenBreakfast = spec.IsOpenBreakfast
		resp.IsOpenLunch = spec.IsOpenLunch
		resp.IsOpenDinner = spec.IsOpenDinner
	}

	//3、查询`central_kitchen_for_school_set`
	centralKitchenForSchoolSetDb := db.CentralKitchenForSchoolSetDb{}
	centralKitchenForSchoolSetDb.Set(enterpriseId)
	set, err := centralKitchenForSchoolSetDb.GetCentralKitchenForSchoolSet()
	if err != nil {
		return
	}
	if set != nil {
		resp.IsOpenTeacherReportMeal = set.IsOpenTeacherReportMeal
		resp.IsOpenReportMealForDay = set.IsOpenReportMealForDay
		resp.IsOpenReportMealForMonth = set.IsOpenReportMealForMonth
		resp.IsOpenReportMealForSemester = set.IsOpenReportMealForSemester
		resp.IsOpenTeacherReportMealForDay = set.IsOpenTeacherReportMealForDay
		resp.IsOpenTeacherReportMealForMonth = set.IsOpenTeacherReportMealForMonth
		resp.IsOpenTeacherReportMealForSemester = set.IsOpenTeacherReportMealForSemester
	}

	//4、统计 "教师"、 "学生"、 "班级" 数量
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	resp.StudentNum, err = userIdentityDb.CountUserIdentityForEnterprise(enterpriseId, enum.UserIdentityForCentralKitchenForStudent)
	if err != nil {
		return
	}
	resp.TeacherNum, err = userIdentityDb.CountUserIdentityForEnterprise(enterpriseId, enum.UserIdentityForCentralKitchenForTeacher)
	if err != nil {
		return
	}
	classDb := db.ClassDb{}
	classDb.Set(0)
	resp.ClassNum, err = classDb.CountClassForEnterprise(enterpriseId)
	if err != nil {
		return
	}
	return
}
